
# gradio-legacyimage
A Custom Gradio component.

Port the Image component in Gradio 3.X to Gradio 4.X. Keep the original APIs and functionalities(Except the data structure of inputs and outputs, there is a slient different).

## Example usage

```python
import gradio as gr
from gradio_legacyimage import LegacyImage
```
